ReportLab Preppy Test Suite 008

# Preppy Test 008 - Testing Preppy With Things That Look Like Integers

This tests to see if Preppy can handle being passed a dictionary with keys that are actually strings, but that look like integers. Arguably every top level dictionary key should be a proper variable identifier and you should not use keys that evaluate to numbers or other Python expressions; but this at least proves it doesn't break.

## Expected Output

You should see four lines of text between these lines.

    This should print a 1: 1
    This should print a 2: 2

    This should print the string in key 1, but is plain daft:
        The key for this dictionary item looks like a number, but is actually a string
    This should print the string in key 2 and is equally daft:
        So is this one - it looks like an integer